pub fn remove_deferred_dispatch<T: Config>(call_hash: T::Hash)Expand description
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::remove_deferred_dispatch.
pub fn remove_deferred_dispatch<T: Config>(call_hash: T::Hash)This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::remove_deferred_dispatch.